@@ -221,28 +221,30 @@ int fors::flat_normaliser::mos_normalise
                                       fit_threshold, slit_spa_norm_profile,
                                       slit_disp_norm_profile);
 
-        //Get a position around the middle of the slit with a valid wave calib
-        int middle_slit = get_middle_slit_valid_calib(wave_cal, yhig, ylow);
+        //Normalisation factor used for flat profile
+        double prof_val_waveref = -1;
+        try
+        {
+            //Get a position around the middle of the slit with a valid wave calib
+            int middle_slit = get_middle_slit_valid_calib(wave_cal, yhig, ylow);
 
-        //Get the pixel of the waveref at the middle of the slit
-        double pix_waveref = wave_cal.get_pixel(middle_slit,
+            //Get the pixel of the waveref at the middle of the slit
+            double pix_waveref = wave_cal.get_pixel(middle_slit,
                                                 wave_cal.get_refwave());
-        int pix_waveref_left = (int)std::floor(pix_waveref);
-        int pix_waveref_rigth = (int)std::ceil(pix_waveref);
-        //Normalise by the value at waveref
-        double prof_val_waveref = 1;
-        if(pix_waveref_left>=0 && pix_waveref_rigth < flat.size_dispersion())
-            prof_val_waveref = (slit_disp_norm_profile[pix_waveref_left] +
-                                slit_disp_norm_profile[pix_waveref_rigth]) / 2.;
+            int pix_waveref_left = (int)std::floor(pix_waveref);
+            int pix_waveref_rigth = (int)std::ceil(pix_waveref);
+            //Normalise by the value at waveref
+            if(pix_waveref_left>=0 && pix_waveref_rigth < flat.size_dispersion())
+                prof_val_waveref = (slit_disp_norm_profile[pix_waveref_left] +
+                                    slit_disp_norm_profile[pix_waveref_rigth]) / 2.;
+        } 
+        catch(std::runtime_error& ex) {} 
+        //get_middle_slit_valid_calib errors ignored
         for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
             slit_disp_norm_profile[i_prof] /= prof_val_waveref;
 
-        //The normalisation factor is divided by the slit length.
-        double prof_waveref_length = prof_val_waveref / 
-                                     slit_spa_norm_profile.size();
-
         m_wave_profiles.push_back(slit_disp_norm_profile);
-        m_wave_profiles_norm.push_back(prof_waveref_length);
+        m_wave_profiles_norm.push_back(prof_val_waveref);
         
         cpl_image * exslit = normslit.get_cpl_image();
         
@@ -485,12 +487,8 @@ int fors::flat_normaliser::lss_normalise
     for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
         slit_disp_norm_profile[i_prof] /= prof_val_waveref;
 
-    //The normalisation factor is divided by the slit length.
-    double prof_waveref_length = prof_val_waveref / 
-                                 flat.size_spatial();
-
     m_wave_profiles.push_back(slit_disp_norm_profile);
-    m_wave_profiles_norm.push_back(prof_waveref_length);
+    m_wave_profiles_norm.push_back(prof_val_waveref);
 
 
     //Finally divide by the smoothed version of the flat.
@@ -542,9 +540,23 @@ const std::vector<std::vector<float> >& fors::flat_normaliser::get_wave_profiles
     return m_wave_profiles;
 }
 
-const std::vector<float>& fors::flat_normaliser::get_wave_profiles_norm() const
+std::vector<float> fors::flat_normaliser::get_wave_profiles_norm
+(double mflat_exptime,
+ const std::vector<float>& slit_widths,
+ const std::vector<float>& slit_lengths) const
 {
-    return m_wave_profiles_norm;
+    if(m_wave_profiles_norm.size() != slit_widths.size() ||
+       m_wave_profiles_norm.size() != slit_lengths.size())
+        throw std::invalid_argument("Vector sizes do not match");
+    std::vector<float> wave_profiles_norm_scaled;
+    
+    for(size_t i = 0; i < m_wave_profiles_norm.size(); ++i)
+    {
+        float scale = mflat_exptime * slit_widths[i] * slit_lengths[i];
+        wave_profiles_norm_scaled.push_back(m_wave_profiles_norm[i] / scale);
+    }
+    
+    return wave_profiles_norm_scaled;
 }
 
 cpl_image * fors::flat_normaliser::get_wave_profiles_im() const
@@ -582,8 +594,13 @@ cpl_image * fors::flat_normaliser::get_wave_profiles_im_mapped
         
         if(slit_begin_pos != -1)
         {
-            int slit_pos_good_wavecal = fors::flat_normaliser::get_middle_slit_valid_calib
+            int slit_pos_good_wavecal = (slit_end_pos - slit_begin_pos) / 2 + slit_begin_pos;
+            try
+            {
+                slit_pos_good_wavecal = fors::flat_normaliser::get_middle_slit_valid_calib
                     (wave_cal, slit_end_pos, slit_begin_pos);
+            }
+            catch(std::runtime_error& ex) {} 
             for(cpl_size i_wave = 0; i_wave < nl; ++i_wave)
             {
                 int null;
