@@ -54,16 +54,16 @@ try:
         if 'OBJECT_TABLE_SCI_'+inst_mode in frames :
           self.object_table = frames['OBJECT_TABLE_SCI_'+inst_mode]
 
-      for inst_mode in {'MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU'} :
+      for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'MAPPED_SCI_'+inst_mode in frames:
           self.sci_mapped   = PlotableMappedScience(frames["MAPPED_SCI_"+inst_mode],
                                                     self.object_table)
           
-      for inst_mode in {'MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU'} :
+      for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'REDUCED_SCI_'+inst_mode in frames:
           self.sci_extracted   = PlotableExtractedScience(frames["REDUCED_SCI_"+inst_mode])
           
-      for inst_mode in {'MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU'} :
+      for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'SKY_SHIFTS_SLIT_SCI_'+inst_mode in frames:
           self.skylines_off   = PlotableSkylinesOffsets(frames["SKY_SHIFTS_SLIT_SCI_"+inst_mode])
           if numpy.isnan(self.skylines_off.allwave_res).all() :
@@ -176,11 +176,11 @@ a constant shift (--skyalign parameter)."""
     def showTextInfo(self) :
       self.subplot_txtinfo.set_axis_off()
       try:
-        grism = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO INS GRIS1 NAME')
+        grism = self.sci_mapped.mappedscience.readKeyword('HIERARCH ESO INS GRIS1 NAME')
       except:
         grism = 'unkown'
       try:
-        filter_name = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO INS FILT1 NAME')
+        filter_name = self.sci_mapped.mappedscience.readKeyword('HIERARCH ESO INS FILT1 NAME')
       except:
         filter_name = 'free'
       self.subplot_txtinfo.text(0.1, 0., 'Grism/Filter: '+grism+'/'+
